package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.Company;

/**
 * 广告主Service接口
 *
 * @author ruoyi
 * @date 2023-05-15
 */
public interface ICompanyService
{
    /**
     * 查询广告主
     *
     * @param id 广告主主键
     * @return 广告主
     */
    public Company selectCompanyById(String id);

    /**
     * 查询广告主列表
     *
     * @param company 广告主
     * @return 广告主集合
     */
    public List<Company> selectCompanyList(Company company);

    /**
     * 新增广告主
     *
     * @param company 广告主
     * @return 结果
     */
    public int insertCompany(Company company);

    /**
     * 修改广告主
     *
     * @param company 广告主
     * @return 结果
     */
    public int updateCompany(Company company);

    /**
     * 批量删除广告主
     *
     * @param ids 需要删除的广告主主键集合
     * @return 结果
     */
    public int deleteCompanyByIds(String ids);

    /**
     * 删除广告主信息
     *
     * @param id 广告主主键
     * @return 结果
     */
    public int deleteCompanyById(String id);
}
